@@ -1,13 +1,15 @@
 package uk.ac.starlink.table;
 
+import java.util.function.LongSupplier;
+
 /**
- * Row sequence implementation which has no rows.
- * Singleton impelementation.
+ * Implementation of both RowSequence and RowAccess which has no rows.
+ * Singleton class.
  * 
  * @since    28 Oct 2004
  * @author   Mark Taylor (Starlink)
  */
-public class EmptyRowSequence implements RowSequence {
+public class EmptyRowSequence implements RowSplittable, RowAccess {
 
     /** Instance. */
     private static final EmptyRowSequence INSTANCE = new EmptyRowSequence();
@@ -25,6 +27,22 @@ public class EmptyRowSequence implements RowSequence {
         return false;
     }
 
+    public void setRowIndex( long irow ) {
+        throw new IllegalArgumentException( "Out of bounds (no data)" );
+    }
+
+    public LongSupplier rowIndex() {
+        return () -> -1L;
+    }
+
+    public RowSplittable split() {
+        return null;
+    }
+
+    public long splittableSize() {
+        return 0;
+    }
+
     /**
      * Always throws IllegalStateException.
      */
